% @Author: Angel Alonso
% Company: Coriant GmbH Muenchen
% Univesity: Politecnico di Torino & Universidad Politecnica de Madrid 

% This returns NLI PSD at f.
% ============================================================
%                           INPUT
% ============================================================
% 
% fiberParams: Type: Struct. It contains fiber parameters (alpha,beta2 and gamma)
% signal: Type: Struct. It contains signal parameters (power,roll-off,Bw and Rs)
% sys: Type: Struct. It contains system parameters (number of channels, 
% span length, number of spans, bw, EDFA Gain, Figure Noise)
% f: Type: Double. Frequency under analysis. Baseband. f=0 central channel [THz]
% fibProf: Double Matrix Type. Power evolution profile
% sigPSD: Double Array. WDM Signal Spectrum [W/Hz]
% zeta_samples: Double Type. It set the number of samples of z
%
% ============================================================
%                           OUTPUT
% ============================================================
%
% GGf: Type: Double. NLI PSD at f [W/Hz]

function GGf = GGNLI_f(fiberParams,signal,sys,f,fibProf,sigPSD, zeta_samples)
nSamples=floor(sys.Bw*23000/8);
f2=linspace(-sys.Bw/2,sys.Bw/2,nSamples);
f1=linspace(-sys.Bw/2,sys.Bw/2,nSamples);
gtx_f2 = sigPSD;
gtx_f1 = gtx_f2;             % PSD Signal f1
I2 = zeros(1,nSamples);      % Inner Integral
II2 = zeros(1,nSamples);      % Inner Integral
n=nSamples;
[c,index] = min(abs(f-f2));
z = linspace(0,sys.Ls,zeta_samples);
fib = zeros(n,length(z));
for i=1:length(z)
    fib(:,i)=interp1(sys.fCh,fibProf(:,i),f2,'cubic');
end
fib_f  = fib(index,:);
fib_f  = sqrt(fib_f);
fib_f  = repmat(fib_f,n,1);

for jj=1:n
    if mod(jj, 100) == 0
        fprintf('%g%% \n', round(jj*100/nSamples))
    end
    %     fprintf('%g \n',jj)
    if gtx_f1(jj) == 0
        I2(jj) = 0;
    else
        f3 =f1(jj)+f2-f;
        if index-jj>=0
            ze = zeros(1,index-jj);
            db = 1i*4*pi^2*(f1(jj)-f)*(f2((index-jj+1):end)-f)*fiberParams.GVD;
            db = reshape(db,length(db),1);
            db = repmat(db,1,length(z));
            Z = repmat(z,size(db,1),1);
            F = db.*Z;
            F = exp(F);
            fib_f1 = fib(jj,:);
            fib_f1 = sqrt(fib_f1);
            fib_f1 = repmat(fib_f1,size(db,1),1);
            fib_f2 = sqrt(fib);
            fib_f3 = fib_f2(1:(n-length(ze)),:);
            test = fib_f1.*fib_f((index-jj+1):end,:).*fib_f2((index-jj+1):end,:)./fib_f3;
            F = F.*test;
            F = trapz(z,F,2);
            F = abs(F).^2;
            F = horzcat(ze,F');
            gtx_f3 = horzcat(ze,gtx_f2(1:(n-length(ze))));
            I2(jj)=trapz(f2,F.*gtx_f1(jj).*gtx_f2.*gtx_f3);
            
        else
            ze = zeros(1,abs(index-jj));
            db = 1i*4*pi^2*(f1(jj)-f)*(f2(1:(end-abs(index-jj)))-f)*fiberParams.GVD;
            db = reshape(db,length(db),1);
            db = repmat(db,1,length(z));
            Z = repmat(z,size(db,1),1);
            F = db.*Z;
            F = exp(F);
            fib_f1 = fib(jj,:);
            fib_f1 = sqrt(fib_f1);
            fib_f1 = repmat(fib_f1,size(db,1),1);
            fib_f3 = fib_f2((1+length(ze)):end,:);
            test = fib_f1.*fib_f(1:(end-abs(index-jj)),:).*fib_f2(1:(end-abs(index-jj)),:)./fib_f3;
            F = F.*test;
            F = trapz(z,F,2);
            F = abs(F).^2;
            F = horzcat(F',ze);
            gtx_f3 = horzcat(gtx_f2(1+length(ze):end),ze);
            I2(jj)=trapz(f2,F.*gtx_f1(jj).*gtx_f2.*gtx_f3);
        end
    end
end
save('I2_12_june_2.mat','I2');
I1=trapz(f1,I2);
GGf=16/27*fiberParams.gamma^2*I1*1e-12;
end


