% @Author: Angel Alonso
% Company: Coriant GmbH Muenchen
% Univesity: Politecnico di Torino & Universidad Politecnica de Madrid 

% This returns NLI PSD at f.
% ============================================================
%                           INPUT
% ============================================================
% 
% fiberParams: Type: Struct. It contains fiber parameters (alpha,beta2 and gamma)
% signal: Type: Struct. It contains signal parameters (power,roll-off,Bw and Rs)
% sys: Type: Struct. It contains system parameters (number of channels, 
% span length, number of spans, bw, EDFA Gain, Figure Noise)
% f: Type: Double. Frequency under analysis. Baseband. f=0 central channel [THz]
% fibProf: Double Matrix Type. Power evolution profile
% sigPSD: Double Array. WDM Signal Spectrum [W/Hz]
% zeta_samples: Double Type. It set the number of samples of z
%
% ============================================================
%                           OUTPUT
% ============================================================
%
% GGf: Type: Double. NLI PSD at f [W/Hz]

function GGf = GGNLI_f_2(fiberParams,signal,sys,f,fibProf,sigPSD, zeta_samples)
nSamples=floor(sys.Bw*23000/8);
f2=linspace(-sys.Bw/2,sys.Bw/2,nSamples);
f1=linspace(-sys.Bw/2,sys.Bw/2,nSamples);
gtx_f2 = sigPSD;
gtx_f1 = gtx_f2;             % PSD Signal f1
nonull = find(not(gtx_f2==0)); 
first_nonull = nonull(1);
last_nonull = nonull(end); 
I2 = zeros(1,nSamples);      % Inner Integral

n=nSamples;
ns_thz = nSamples/sys.Bw;
ns_ch = floor(signal.BwCh*ns_thz);
ns_gap = floor(ns_thz*(sys.delta_f-signal.BwCh));
[c,index] = min(abs(f-f2));
z = linspace(0,sys.Ls,zeta_samples);
fib = zeros(n,length(z));
for i=1:length(z)
    fib(:,i)=interp1(sys.fCh,fibProf(:,i),f2,'cubic');
end
fib_f  = fib(index,:);
fib_f  = sqrt(fib_f);


for jj=1:n

    if mod(jj, 100) == 0
        fprintf('%g%% \n', round(jj*100/nSamples))
    end
    %     fprintf('%g \n',jj)
    if gtx_f1(jj) == 0
        I2(jj) = 0;
    else
        if index-jj>=0
            if abs(index-jj)<50
                
            end
            ze = zeros(1,index-jj);
            id_f3 = horzcat(ze,(1:n-length(ze)));
            for kk = 1:sys.nCh %loop for every channel.
                low = (ns_ch+ns_gap+1)*(kk-1) + first_nonull;
                high = (ns_ch+ns_gap+1)*(kk-1) + ns_ch+first_nonull;
                id_f3_k = id_f3(low:high);
                null_f3 = find(id_f3_k == 0);
                if isempty(null_f3)
                    in=0;
                else
                    in = null_f3(end);
                end
                id_f3_k_real = id_f3_k(in+1:end);
                id_f2_k_real = (low+in):high;
                db = 1i*4*pi^2*(f1(jj)-f)*(f2(id_f2_k_real)-f)*fiberParams.GVD;
                db = reshape(db,length(db),1);
                db = repmat(db,1,length(z));
                Z = repmat(z,size(db,1),1);
                F = db.*Z;
                F = exp(F);
                fibb_f  = repmat(fib_f,size(db,1),1);
                fib_f1 = fib(jj,:);
                fib_f1 = sqrt(fib_f1);
                fib_f1 = repmat(fib_f1,size(db,1),1);
                fib_f2 = fib(id_f2_k_real,:);
                fib_f2 = sqrt(fib_f2);
                fib_f3 = fib(id_f3_k_real,:);
                fib_f3 = sqrt(fib_f3);   
                test = fib_f1.*fibb_f.*fib_f2./fib_f3;
                F = F.*test;
                F = trapz(z,F,2);
                F = abs(F).^2;
                F = F.';
                A = gtx_f2(id_f2_k_real);
                B = gtx_f2(id_f3_k_real);
                freq = f2(id_f2_k_real);
                I2(jj)=I2(jj)+trapz(freq,F.*gtx_f1(jj).*A.*B,2);
            end
            
        else 
            ze = zeros(1,abs(index-jj));
            id_f3 =horzcat(1+length(ze):n,ze);
            for kk = 1:sys.nCh
                low = (ns_ch+ns_gap+1)*(kk-1) + first_nonull;
                high = (ns_ch+ns_gap+1)*(kk-1) + ns_ch+first_nonull;
                id_f3_k = id_f3(low:high);
                null_f3 = find(id_f3_k == 0);
                if isempty(null_f3)
                    fin=0;
                else
                    fin = length(null_f3);
                end
                id_f3_k_real = id_f3_k(1:end-fin);
                id_f2_k_real = (low:high-fin);
                db = 1i*4*pi^2*(f1(jj)-f)*(f2(id_f2_k_real)-f)*fiberParams.GVD;
                db = reshape(db,length(db),1);
                db = repmat(db,1,length(z));
                Z = repmat(z,size(db,1),1);
                F = db.*Z;
                F = exp(F);
                fibb_f  = repmat(fib_f,size(db,1),1);
                fib_f1 = fib(jj,:);
                fib_f1 = sqrt(fib_f1);
                fib_f1 = repmat(fib_f1,size(db,1),1);
                fib_f2 = fib(id_f2_k_real,:);
                fib_f2 = sqrt(fib_f2);
                fib_f3 = fib(id_f3_k_real,:);
                fib_f3 = sqrt(fib_f3);   
                test = fib_f1.*fibb_f.*fib_f2./fib_f3;
                F = F.*test;
                F = trapz(z,F,2);
                F = abs(F).^2;
                F = F.';
                A = gtx_f2(id_f2_k_real);
                B = gtx_f2(id_f3_k_real);
                freq = f2(id_f2_k_real);
                I2(jj)=I2(jj)+trapz(freq,F.*gtx_f1(jj).*A.*B,2);
            end
        end



    end

end
I1=trapz(f1,I2);
save('i2_20180617.mat','I2');
GGf=16/27*fiberParams.gamma^2*I1*1e-12;
end


