
% @Author: Angel Alonso
% Company: Coriant GmbH Muenchen
% Univesity: Politecnico di Torino & Universidad Politecnica de Madrid 

% This returns power profile at the end of the span rh(Ls,f)^2
% ============================================================
%                           INPUT
% ============================================================
% 
% power: Type: Double array. channel power
% Cr: Type: Double. Raman Gain [1/W/km]
% fMax: Type: Double. Frequency shift, so Raman Gain is equal to Cr [THz]
% alpha: Type: Double array.  field attenuation factor [1/km]
% delta_f: Type: Double. Frequency spacing [THz]
% Ls: Type: Double. Span length [km]
% n: Type: Double. Channel index
% nCh: Type: Integer. Number of Channels
% J: Type: Double. Total Input Power [W]
% ============================================================
%                           OUTPUT
% ============================================================
%
% rho: Type: Double. Power profile at the of the span


function rho = fiber(power,Cr,fMax,alpha,delta_f,Ls,n,nCh,J)


    % First of all we compute the slope of the Raman Gain Profile (This slope
    % includes 1/2Aeff
    % m = g'/2A
%     slope = 4.9e-18; 
%     Aeff = 50e-12;
%     G = slope/2/Aeff*delta_f*1000;
    m = Cr/fMax;
    G = m*delta_f;
    Leff = (1-exp(-2*alpha*Ls))/(2*alpha); % Effective Length 
    A = 0;
    for ii = 1:nCh 
        A  =  A + (power(ii)*exp(G*J*(ii-1)*Leff));
    end
    rho = J*exp(-2*alpha*Ls)*exp(G*J*(n-1)*Leff)/A;
  

end