
% @Author: Angel Alonso
% Company: Coriant GmbH Muenchen
% Univesity: Politecnico di Torino & Universidad Politecnica de Madrid 

% This returns power evolution profile rho(z,f)^2.
% ============================================================
%                           INPUT
% ============================================================
% 
% power: Type: Double array. channel power
% Cr: Type: Double. Raman Gain [1/W/km]
% fMax: Type: Double. Frequency shift, so Raman Gain is equal to Cr [THz]
% alpha: Type: Double array.  field attenuation factor [1/km]
% delta_f: Type: Double. Frequency spacing [THz]
% Ls: Type: Double. Span length [km]
% n: Type: Double. Channel index
% nCh: Type: Integer. Number of Channels
% J: Type: Double. Total Input Power [W]
% zeta_samples: Double Type. It set the number of samples of z
%
% ============================================================
%                           OUTPUT
% ============================================================
%
% rho: Type: Double Array. Power evolution profile.

function rho = fiber_var(power,Cr,fMax,alpha,delta_f,Ls,n,nCh,J, zeta_samples)


    % First of all we compute the slope of the Raman Gain Profile (This slope
    % includes 1/2Aeff
    % m = g'/2A
%     slope = 4.9e-18; 
%     Aeff = 50e-12;
%     G = slope/2/Aeff*delta_f*1000;
    m = Cr/fMax;
    G = m*delta_f;
    z = linspace(0,Ls, zeta_samples);
    Leff = (1-exp(-2*alpha(n).*z))./(2*alpha(n)); % Effective Length 
    A = zeros(nCh,length(z));
    for ii = 1:nCh  
        A(ii,:)  =  A(ii,:) + (power(ii).*exp(G*J*(ii-1).*Leff));
    end
    A = sum(A,1);
    rho = J*exp(-2*alpha(n).*z).*exp(G*J*(n-1).*Leff)./A;
end