% @Author: Angel Alonso
% Company: Coriant GmbH Muenchen
% Univesity: Politecnico di Torino & Universidad Politecnica de Madrid 

% This returns signal and sys structs
                                 

% ============================================================
%                           INPUT
% ============================================================
% 
% delta_f: Type: Double. Spacing frequency
% nCh: Type: Double. Number of samples
% power: Type: Double. Input Channel power
% article: Type: String. switch flag
%
% ============================================================
%                           OUTPUT
% ============================================================
%
% signal: Type: Struct. It contains signal parameters (power,roll-off,Bw and Rs)
% sys: Type: Struct. It contains system parameters (number of channels, 
% span length, number of spans, bw, EDFA Gain, Figure Noise)
function [signal,sys]=systemParams(delta_f,nCh,power,article)

switch article 
    case 'CORIANT3'
        c = 299792458; % Speed Light in vacuum
        
           % WDM Signal parameters
        roll_off = 0.15; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh); 
        
        % System parameters
        fo =  191.1250; % Central Wavelegnth [nm]
        lo = c/(fo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 20; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 100.8; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);
    case 'CORIANT2'
        c = 299792458; % Speed Light in vacuum
        
           % WDM Signal parameters
        roll_off = 0.15; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh); 
        
        % System parameters
        fo =  191.6250; % Central Wavelegnth [nm]
        lo = c/(fo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 20; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 100.8; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);
    case 'CORIANT'
        c = 299792458; % Speed Light in vacuum
        
           % WDM Signal parameters
        roll_off = 0.15; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh); 
        
        % System parameters
        fo = 193.15; % Central Wavelegnth [nm]
        lo = c/(fo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 16.2893; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 100.8; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);
    case 'ORANGE'
        % Modelling the Impact of SRS on NLI Generation in Commercial
        % Equipment: an Experimental investigation
        % Mattia Cantono
        % Physical parameters/constants 
        c = 299792458; % Speed Light in vacuum
        
           % WDM Signal parameters
        roll_off = 0.15; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh); 
        
        % System parameters
        fo = 193.9778; % Central Wavelegnth [nm]
        lo = c/(fo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 16; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 80; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);
    case 'TIM'
         
        c = 299792458; % Speed Light in vacuum

        % WDM Signal parameters
        roll_off = 0.2; % Roll-off factor
        Rs = 57.24e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh);
        
        % System parameters
        fo = 193.4;
        F = 6.5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 24.1740; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 76.5; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 10; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);

    case 'M1D.2'
        % Modelling the Impact of SRS on NLI Generation in Commercial
        % Equipment: an Experimental investigation
        % Mattia Cantono
        % Physical parameters/constants  
        c = 299792458; % Speed Light in vacuum

        % WDM Signal parameters
        roll_off = 0.2; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh);
        
        % System parameters
        lo = 1545.3; % Central Wavelegnth [nm]
        fo = c/(lo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 16; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 80; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);

    case '111Fig4a'
        % 111 stands for the article called:
        % Modeling of the Impact of Nonlinear Propagation Effects
        % in Uncompensated Optical Coherent Transmission Links 
        % Figure 4.a
        % First Author: Andrea Carena
        
        % Physical parameters/constants  
        c = 299792458; % Speed Light in vacuum

        % WDM Signal parameters
        roll_off = 0.3; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh);

        % System parameters
        lo = 1550; % Central Wavelegnth [nm]
        fo = c/(lo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 22; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 100; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);
    
    case '111Fig4b'
        % 111 stands for the article called:
        % Modeling of the Impact of Nonlinear Propagation Effects
        % in Uncompensated Optical Coherent Transmission Links
        % Figure 4.b
        % First Author: Andrea Carena
        
        % Physical parameters/constants  
        c = 299792458; % Speed Light in vacuum

        % WDM Signal parameters
        roll_off = 0.3; % Roll-off factor
        Rs = 32e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh);

        % System parameters
        lo = 1550; % Central Wavelegnth [nm]
        fo = c/(lo*10^3); % Central Frquency [THz]
        F = 5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 18; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 100; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);        
    case 'C+LW1I.2'
        % c+L W1I.2 stands for the article called:
        % "DP-16QAM Based Coded Modulation Transmission
        % in C+L Band System at Transoceanic Distance" 
        % First Author: H.Zhang
        
        % Physical parameters/constants  
        c = 299792458; % Speed Light in vacuum

        % WDM Signal parameters
        roll_off = 0.01; % Roll-off factor
        Rs = 34.18e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh);

        % System parameters
        lo = 1546; % Central Wavelegnth [nm]
        fo = c/(lo*10^3); % Central Frquency [THz]
        F = 5.2; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 9.9; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 55; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 121; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo); 
    case '7fiber_SSMF'
        % 111 stands for the article called:
        % Modeling of the Impact of Nonlinear Propagation Effects
        % in Uncompensated Optical Coherent Transmission Links
        % Figure 4.b
        % First Author: Andrea Carena
        
        % Physical parameters/constants  
        c = 299792458; % Speed Light in vacuum

        % WDM Signal parameters
        roll_off = 0.01; % Roll-off factor
        Rs = 15.625e-3; % Channel Rate [TBaud/s]
        power=10.^(power/10); 
        BwCh = (1+roll_off)*Rs; % Channel Bandwith
        signal=struct('roll_off',roll_off,'Rs',Rs,'power',power,'BwCh',BwCh);

        % System parameters
        lo = 1550; % Central Wavelegnth [nm]
        fo = c/(lo*10^3); % Central Frquency [THz]
        F = 5.5; % Noise Figure [dB]
        Flin = 10^(F/10); % Noise Figure in Linear Scale 
        G = 9.7014; % EDFA Amplifier Gain [dB]
        Glin = 10^(G/10); % EDFA Amplifier Gain in Linear Scale 
        Ls = 51.06; % span length [km]
        %delta_f = 32e-3; % Frequency spacing between channels Nyquist delta_f=BwCh. Usually delta_f=3/2 BwCh
        Bw = nCh*delta_f;
        Ns = 1; % Spans number
        fCh=(-Bw/2-delta_f/2)*ones(1,nCh)+delta_f*(1:nCh);
        sys=struct('Flin',Flin,'GLin',Glin,'Ls',Ls,'nCh',nCh,'delta_f',delta_f,'Bw',Bw,'Ns',Ns,'fCh',fCh,'fo',fo);
        
end





